Function rusty_parser::chars
source · pub fn chars<'a>(str: &'a str) -> SliceEqualParser<Chars<'a>>Expand description
This Parser will compare the input string starts with the given string.
pub fn chars<'a>(str: &'a str) -> SliceEqualParser<Chars<'a>>This Parser will compare the input string starts with the given string.