Function rusty_parser::one
source · pub fn one<CharType>(ch: CharType) -> SingleEqualParser<CharType>Expand description
Check one character is equal to the given character.
pub fn one<CharType>(ch: CharType) -> SingleEqualParser<CharType>Check one character is equal to the given character.