Function rusty_parser::optional
source · pub fn optional<ParserType: IntoParser>(
parser: ParserType
) -> OptionalParser<ParserType::Into>Expand description
this parser always success whether the input is matched or not
pub fn optional<ParserType: IntoParser>(
parser: ParserType
) -> OptionalParser<ParserType::Into>this parser always success whether the input is matched or not