Function rusty_parser::string
source · pub fn string<ParserType>(parser: ParserType) -> StringParser<ParserType>Expand description
returns String of parsed input only works for parsing with std::str::Chars
pub fn string<ParserType>(parser: ParserType) -> StringParser<ParserType>returns String of parsed input only works for parsing with std::str::Chars