Struct rusty_parser::DynBoxChars

source ·
pub struct DynBoxChars<Output>
where Output: Tuple,
{ /* private fields */ }
A Box<dyn Parser> wrapper for iterators of std::str::Chars.

This can take any parser with Output of Output.

Once you wrap the parser with this, you can only use input iterator of std::str::Chars.

Implementations

source

impl<Output> DynBoxChars<Output>
where Output: Tuple,

source

pub fn new<ParserType: IntoParser>(parser: ParserType) -> Self
where ParserType::Into: for<'a> Parser<Chars<'a>, Output = Output> + 'static,

source

pub fn assign<ParserType: IntoParser>(&mut self, parser: ParserType)
where ParserType::Into: for<'a> Parser<Chars<'a>, Output = Output> + 'static,