Struct rusty_parser::DynBoxChars
source · pub struct DynBoxChars<Output>where
Output: Tuple,{ /* private fields */ }Expand description
A Box<dyn Parser> wrapper for iterators of std::str::Chars.
This can take any parser with Output of Output.
Once you wrap the parser with this, you can only use input iterator of std::str::Chars.
Implementations
sourceimpl<Output> DynBoxChars<Output>where
Output: Tuple,
impl<Output> DynBoxChars<Output>where
Output: Tuple,